pub enum CheckElement {
Yes,
No,
}Expand description
Indicates whether we should check if deserialized are valid
points on the curves.
No indicates to skip those checks, which is by orders of magnitude
faster, but could potentially result in undefined behaviour. Use
only with care.
Variants