pub enum WitnessParserError {
IoError(Error),
SerializationError(SerializationError),
VersionNotSupported(u32, u32),
InvalidSectionNumber(u32, u32),
WrongScalarField,
WrongHeader(InvalidHeaderError),
}Expand description
Error type describing errors during parsing witness files
Variants
IoError(Error)
Error during IO operations (reading/opening file, etc.)
SerializationError(SerializationError)
Error during serialization
VersionNotSupported(u32, u32)
Error describing that the version of the file is not supported for parsing
InvalidSectionNumber(u32, u32)
Error describing that the number of sections in the file is invalid
WrongScalarField
Error describing that the ScalarField from curve does not match in witness file
WrongHeader(InvalidHeaderError)
Error during reading Circom file header